( cd usr/share/doc/HTML/ca/kchart ; rm -rf common )
( cd usr/share/doc/HTML/ca/kchart ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/karbon ; rm -rf common )
( cd usr/share/doc/HTML/ca/karbon ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/krita ; rm -rf common )
( cd usr/share/doc/HTML/ca/krita ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kplato ; rm -rf common )
( cd usr/share/doc/HTML/ca/kplato ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kugar ; rm -rf common )
( cd usr/share/doc/HTML/ca/kugar ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kspread ; rm -rf common )
( cd usr/share/doc/HTML/ca/kspread ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kword ; rm -rf common )
( cd usr/share/doc/HTML/ca/kword ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/koffice ; rm -rf common )
( cd usr/share/doc/HTML/ca/koffice ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/thesaurus ; rm -rf common )
( cd usr/share/doc/HTML/ca/thesaurus ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kpresenter ; rm -rf common )
( cd usr/share/doc/HTML/ca/kpresenter ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/koshell ; rm -rf common )
( cd usr/share/doc/HTML/ca/koshell ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kivio ; rm -rf common )
( cd usr/share/doc/HTML/ca/kivio ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kformula ; rm -rf common )
( cd usr/share/doc/HTML/ca/kformula ; ln -sf /usr/share/doc/HTML/ca/common common )
( cd usr/share/doc/HTML/ca/kexi ; rm -rf common )
( cd usr/share/doc/HTML/ca/kexi ; ln -sf /usr/share/doc/HTML/ca/common common )
